create_patched_cmd

Function create_patched_cmd 

pub fn create_patched_cmd(
    args: Vec<String>,
    config: Config,
    prog: PathBuf,
) -> Result<Command, Error>
Attempts to create a Command that has its PATH prepended with a Config’s version directory.

This method can be independently used in order to run custom commands, or to customize how the Command should run.