haxe_exec

Function haxe_exec 

pub fn haxe_exec(
    args: Vec<String>,
    config: Config,
    prog: Option<String>,
) -> Result<Output, Error>
Executes a specified program under a version directory.

libmask will check ahead of time if the program specified is available as a safety precaution, and will otherwise fail if the program cannot be accessed.

Programs executed will have their PATH environment variable prepended with the Haxe version directory the program is in. This is primarily useful for programs like build tools, because they will typically expect, as an example, the compiler or Haxelib to be available. Alongside this, all standard stdio streams are inherited for live input and output.